@@ -44,6 +44,9 @@ def process_snapshot_date_parameter(parameter: Optional[datetime]) -> Optional[s
 def process_updates_date_parameter(parameter: Optional[datetime]) -> Optional[str]:
     return parameter.strftime('%Y-%m-%dT%H%M%S') if parameter else None
 
+def process_flow_snapshot_parameter(parameter: Optional[datetime]) -> Optional[str]:
+    return parameter.strftime('%Y-%m-%d') if parameter else None
+
 def process_enum_parameters(
     parameter: Optional[List[enum.Enum]], to_lower_case: bool = True
 ) -> Optional[str]:
