@@ -88,7 +88,7 @@ class Trades(KplerClient):
             with_intra_country: Optional[bool] By default: withIntraCountry=true. Takes into account the trades within the selected region. Use ["true", "false"]
             columns: Optional[List[str]] Retrieve all available columns when set to "all"
             with_freight_view: bool By default: with_freight_view=False. Provides access to the entire fleet's trades, irrespective of your current cargo subscription. Only available via Freight subscription.
-            with_product_estimation: bool By default withProductEstimation=False. Activate the product estimation feature for CPP trades only. When set to true, the estimated product will overwrite the existing product information.
+            with_product_estimation: bool By default withProductEstimation=False. Activate the product estimation feature. When set to true, the estimated product will overwrite the existing product information.
         Examples:
             >>> from datetime import date, timedelta
             ... from kpler.sdk.resources.trades import Trades
